| MOPTAN | R Documentation |
Perform a TAN model of class MoTBF based on maximizing the Mutual Information.
fit_tan(
target,
data,
fit.args = NULL,
root = NULL,
all = FALSE,
mutualInfoCond = NULL,
parallel = FALSE
)
mutual_information_tan(data, target, fit.args = NULL, parallel = FALSE)
target |
A |
data |
A |
fit.args |
A |
root |
A |
all |
A |
mutualInfoCond |
A numeric matrix indicating the estimation of the
mutual information coefficientes for Chow-Liu- algorithm in TAN. If it is
|
parallel |
A |
The main function, fit_tan(), fits a MoTBF Tree Augmented Naive Bayes
model using the specified data.
The main function, fit_tan(), returns an object of class "motbf_fit".
When all=TRUE, it returns a list with the Bayesian network and the mutual
information matrix used to compute the maximun spanning tree.
Function mutual_information_tan() returns a symmetric numeric
matrix of dimensions k \times k, where k is the number of
predictor variables. Row and column names correspond to the predictor
variables, and the entries contain the estimated conditional mutual
information values. This matrix is used to compute the TAN model.
data = iris
data$Species = as.factor(data$Species)
# Fit TAN model for classification
tan = fit_tan("Species",data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.