confusionMatrix: Confusion Matrix

View source: R/crossValidation.R

confusionMatrixR Documentation

Confusion Matrix

Description

Computes the confusion matrix for a given fitted model object.

Usage

confusionMatrix(x, ...)

## S3 method for class 'motbf_fit_cv'
confusionMatrix(x, digits = 4, ...)

Arguments

x

An object used to select the appropriate method, such as one of class 'motbf_fit_cv'.

...

Further arguments. Not used currently.

digits

An integer indicating the number of decimal places to round the results.

Value

A matrix or table containing the confusion matrix.


MoTBFs documentation built on Oct. 6, 2026, 1:06 a.m.