evalJointFunction: Evaluation of joint MoTBFs

View source: R/Deprecated.R

evalJointFunctionR Documentation

Evaluation of joint MoTBFs

Description

Evaluates a "jointmotbf" object at a specific point. This function is deprecated; use "eval.mop" instead.

Usage

evalJointFunction(P, values)

Arguments

P

A "jointmotbf" object.

values

A list with the name of the variables equal to the values to be evaluated.

Value

If all the variables in the equation are evaluated then a "numeric" value is returned. Otherwise, an "motbf" object or a "jointmotbf" object is returned.


MoTBFs documentation built on Oct. 6, 2026, 1:06 a.m.