getMotbfVar: Extract Variables of MoTBFs

View source: R/joint.R

getMotbfVarR Documentation

Extract Variables of MoTBFs

Description

Get the names of the variables involved in a "univmotbf" or jointmotbf object.

Usage

getMotbfVar(P)

Arguments

P

An object of class "univmotbf" or "jointmotbf".

Value

A "character" vector with the names of the variables in the function.

Examples


# 1. EXAMPLE
## Generate a dataset
data <- data.frame(X1 = rnorm(100), X2 = rnorm(100))

## Joint function
dim <-c(3,2)
P <- jointmotbf.fit(data, dimensions = dim)
P

## Variables
getMotbfVar(P)

##############################################################################
## MORE EXAMPLES #############################################################
##############################################################################

## Generate a dataset
data <- data.frame(X1 = rnorm(100), X2 = rnorm(100), X3 = rnorm(100))

## Joint function
dim <- c(2,1,3)
P <- jointmotbf.fit(data, dimensions = dim)

## Variables
getMotbfVar(P)


MoTBFs documentation built on Oct. 6, 2026, 1:06 a.m.