Learn R Programming

MoTBFs (version 2.0)

integralJointMoTBF: Integration with MoTBFs

Description

Integrate a "jointmotbf" object over an non defined domain. It is able to get the integral of a joint function over a set of variables or over all the variables in the function. This function is deprecated; use "integrate.motbf" instead.

Usage

integralJointMoTBF(P, var = NULL)

Value

A multiintegral of a joint function of class "jointmotbf".

Arguments

P

A "jointmotbf" object.

var

A "character" vector containing the name of the variables that will be integrated out. Instead of the names, the position of the variables can be given. By default it's NULL then all the variables are integrated out.