Compute the integral of a one-dimensional mixture of truncated basis function
over a bounded or unbounded interval.
This function is deprecated; use "integrate.motbf" instead.
integralMoTBF(fx, min = NULL, max = NULL)integralMoTBF() returns either the indefinite integral of the MoTBF
function, which is also an object of class "motbf", or the definite integral,
wich is a "numeric" value.
An object of class "motbf".
The lower integration limit. By default it is NULL.
The upper integration limit. By default it is NULL.
If the limits of the interval, min and max are NULL, then the output is the expression of the indefinite integral. If only 'min' contains a numeric value, then the expression of the integral is evaluated at this point.
univMoTBF, integralMOP and integralMTE