| is.motbf | R Documentation |
Utility functions to check whether an object belongs to a specific MoTBF class, or to identify its underlying subclass ('mop' or 'mte').
is.motbf(x, class = "motbf")
is.univmotbf(x, class = "univmotbf")
is.jointmotbf(x, class = "jointmotbf")
is.motbf_fit(x, class = "motbf_fit")
is.motbf_fit_cv(x, class = "motbf_fit_cv")
is.mte(x)
is.mop(x)
subclass(fx)
x |
An object to be checked. |
class |
Character string specifying the target class name. |
fx |
An object to determine the subclass for. |
is.*: Logical value (TRUE or FALSE) indicating if the object belongs to the checked class.
subclass: A character string ("mop" or "mte") specifying the underlying family of the object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.