| jointmotbf.fit | R Documentation |
Function for learning joint MoTBFs.
The jointmotbf.fit() function is a wrapper of two internal (non-exported) functions:
getParamJoint() and fixParamJoint().
The first one gets the parameters by solving a quadratic optimization problem, minimizing
the mean squared error between the empirical joint CDF and the estimated CDF.
The density is obtained as the derivative of the estimated CDF.
The second one, fixParamJoint(), fixes the equation of the joint function using
the previously learned parameters and converting this "character" string into an
object of class "jointmotbf".
jointmotbf.fit(
X,
ranges = NULL,
dimensions = NULL,
fitPoints = 10,
constraints = 10
)
X |
a dataset of class |
ranges |
a |
dimensions |
a |
fitPoints |
an |
constraints |
an |
jointmotbf.fit() returns a list with the following elements:
Function |
The analytical expression of the learned density. |
Domain |
A |
Iterations |
The number of iterations needed to solve the problem. |
Time |
The execution time. |
## 1. EXAMPLE
## Generate a multinormal dataset
data <- data.frame(X1 = rnorm(100), X2 = rnorm(100))
## Joint learnings
dim <- c(2,3)
P <- jointmotbf.fit(data, dimensions = dim)
P
attributes(P)
class(P)
###############################################################################
## MORE EXAMPLES ##############################################################
###############################################################################
## Generate a dataset
data <- data.frame(X1 = rnorm(100), X2 = rnorm(100), X3 = rnorm(100))
## Joint learnings
dim <- c(3,2,3)
P <- jointmotbf.fit(data, dimensions = dim)
P
attributes(P)
class(P)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.