nVariables: Number of Variables in a Joint Function

View source: R/Deprecated.R

nVariablesR Documentation

Number of Variables in a Joint Function

Description

Compute the number of variables which are in a jointmotbf object. This function is deprecated; use "getMotbfVar" instead.

Usage

nVariables(P)

Arguments

P

An "motbf" object or a "jointmotbf" object.

Value

A "character" vector with the names of the variables in the function.


MoTBFs documentation built on Oct. 6, 2026, 1:06 a.m.