| predict.motbf_fit | R Documentation |
Predict from an MoTBF Bayesian Network
## S3 method for class 'motbf_fit'
predict(
object,
target,
data,
method = NULL,
prob = FALSE,
parallel = FALSE,
...
)
object |
An object of class "motbf_fit" |
target |
A character string indicating the variable to be predicted |
data |
A data frame containing the predictive variables |
method |
A character string indicating the method to perform the inference. Options are NULL, "ve" (variable elimination) and "fs" (forward sampling). |
prob |
A logical value. If TRUE, the probabilities used for classification are returned as an attribute. |
parallel |
A logical value. If TRUE, parallelization is carried out. |
... |
Additional arguments used if method = "fs". |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.