| print.motbf | R Documentation |
print method for class "motbf".Print object of class motbf
print method for class "motbf".
Print a single node of a BN. This function is called by print.motbf_fit, but not exported.
Print the results of a k-fold cross validation
## S3 method for class 'motbf'
print(x, ...)
## S3 method for class 'motbf_fit'
print(x, ...)
## S3 method for class 'motbf.fit.node'
print(x, ...)
## S3 method for class 'motbf_fit_cv'
print(x, ...)
## S3 method for class 'univmotbf'
print(x, ...)
## S3 method for class 'piecewisemop'
print(x, ...)
## S3 method for class 'jointmotbf'
print(x, ...)
x |
An object of class |
... |
optional arguments passed to print for other classes created in the MoTBFs package. Currently, no optional arguments are supported. |
The following classes are created in the MoTBFs package:
the generic class common to all objects created in the package
the class corresponding to MTE or MOP univariate distributions. An object of class univmotbf is the output of function univMoTBF().
the class corresponding to MOP univariate distributions defined by multiple sub-functions with different domain. When calling variableElimination(), the output might be of this class.
the class corresponding to joint distributions. An object of class jointmotbf is the output of function jointMOP()
the class corresponding to fully fitted Bayesian network models (either discrete, continuous or hybrid). An object of class motbf_fit is the output of function motbf.fit().
the class corresponding to k-fold cross validation results. An object of class motbf.fit.cv is the output of function motbf.cv().
the class corresponding to a single node of a Bayesian Network.
## Dataset Ecoli
data(ecoli)
data <- ecoli[,-c(1)] ## remove variable sequence
## Directed acyclic graph
dag <- LearningHC(data)
## Learning BN
P <- motbf.fit(graph = dag, data = data, numIntervals = 3, POTENTIAL_TYPE = "MOP",
maxParam = 15)
P
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.