View source: R/crossValidation.R
| confusionMatrix | R Documentation |
Computes the confusion matrix for a given fitted model object.
confusionMatrix(x, ...)
## S3 method for class 'motbf_fit_cv'
confusionMatrix(x, digits = 4, ...)
x |
An object used to select the appropriate method, such as one of class |
... |
Further arguments. Not used currently. |
digits |
An integer indicating the number of decimal places to round the results. |
A matrix or table containing the confusion matrix.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.