Learn R Programming

MoTBFs (version 2.0)

confusionMatrix: Confusion Matrix

Description

Computes the confusion matrix for a given fitted model object.

Usage

confusionMatrix(x, ...)

# S3 method for motbf_fit_cv confusionMatrix(x, digits = 4, ...)

Value

A matrix or table containing the confusion matrix.

Arguments

x

An object used to select the appropriate method, such as one of class 'motbf_fit_cv'.

...

Further arguments. Not used currently.

digits

An integer indicating the number of decimal places to round the results.