Computes the confusion matrix for a given fitted model object.
confusionMatrix(x, ...)# S3 method for motbf_fit_cv
confusionMatrix(x, digits = 4, ...)
A matrix or table containing the confusion matrix.
An object used to select the appropriate method, such as one of class 'motbf_fit_cv'.
Further arguments. Not used currently.
An integer indicating the number of decimal places to round the results.