| evalJointFunction | R Documentation |
Evaluates a "jointmotbf" object at a specific point.
This function is deprecated; use "eval.mop" instead.
evalJointFunction(P, values)
P |
A |
values |
A list with the name of the variables equal to the values to be evaluated. |
If all the variables in the equation are evaluated then a "numeric" value
is returned. Otherwise, an "motbf" object or a "jointmotbf" object is returned.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.