Learn R Programming

MoTBFs (version 2.0)

evalJointFunction: Evaluation of joint MoTBFs

Description

Evaluates a "jointmotbf" object at a specific point. This function is deprecated; use "eval.mop" instead.

Usage

evalJointFunction(P, values)

Value

If all the variables in the equation are evaluated then a "numeric" value is returned. Otherwise, an "motbf" object or a "jointmotbf" object is returned.

Arguments

P

A "jointmotbf" object.

values

A list with the name of the variables equal to the values to be evaluated.