Evaluates a "jointmotbf" object at a specific point.
This function is deprecated; use "eval.mop" instead.
evalJointFunction(P, values)If all the variables in the equation are evaluated then a "numeric" value
is returned. Otherwise, an "motbf" object or a "jointmotbf" object is returned.
A "jointmotbf" object.
A list with the name of the variables equal to the values to be evaluated.