Integrate a "jointmotbf" object over an non defined domain. It is able to
get the integral of a joint function over a set of variables or over all
the variables in the function.
This function is deprecated; use "integrate.motbf" instead.
integralJointMoTBF(P, var = NULL)A multiintegral of a joint function of class "jointmotbf".
A "jointmotbf" object.
A "character" vector containing the name of the variables that will be integrated out.
Instead of the names, the position of the variables can be given.
By default it's NULL then all the variables are integrated out.