Learn R Programming

MoTBFs (version 2.0)

is.motbf: Check MoTBF Classes and Subclasses

Description

Utility functions to check whether an object belongs to a specific MoTBF class, or to identify its underlying subclass ('mop' or 'mte').

Usage

is.motbf(x, class = "motbf")

is.univmotbf(x, class = "univmotbf")

is.jointmotbf(x, class = "jointmotbf")

is.motbf_fit(x, class = "motbf_fit")

is.motbf_fit_cv(x, class = "motbf_fit_cv")

is.mte(x)

is.mop(x)

subclass(fx)

Value

  • is.*: Logical value (TRUE or FALSE) indicating if the object belongs to the checked class.

  • subclass: A character string ("mop" or "mte") specifying the underlying family of the object.

Arguments

x

An object to be checked.

class

Character string specifying the target class name.

fx

An object to determine the subclass for.