| nVariables | R Documentation |
Compute the number of variables which are in a jointmotbf object.
This function is deprecated; use "getMotbfVar" instead.
nVariables(P)
P |
An |
A "character" vector with the names of the variables in the function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.