Learn R Programming

MoTBFs (version 2.0)

nVariables: Number of Variables in a Joint Function

Description

Compute the number of variables which are in a jointmotbf object. This function is deprecated; use "getMotbfVar" instead.

Usage

nVariables(P)

Value

A "character" vector with the names of the variables in the function.

Arguments

P

An "motbf" object or a "jointmotbf" object.