powered by
Compute the number of variables which are in a jointmotbf object. This function is deprecated; use "getMotbfVar" instead.
jointmotbf
"getMotbfVar"
nVariables(P)
A "character" vector with the names of the variables in the function.
"character"
An "motbf" object or a "jointmotbf" object.
"motbf"
"jointmotbf"