Learn R Programming

MoTBFs (version 2.0)

predict.motbf_fit: Predict from an MoTBF Bayesian Network

Description

Predict from an MoTBF Bayesian Network

Usage

# S3 method for motbf_fit
predict(
  object,
  target,
  data,
  method = NULL,
  prob = FALSE,
  parallel = FALSE,
  ...
)

Arguments

object

An object of class "motbf_fit"

target

A character string indicating the variable to be predicted

data

A data frame containing the predictive variables

method

A character string indicating the method to perform the inference. Options are NULL, "ve" (variable elimination) and "fs" (forward sampling).

prob

A logical value. If TRUE, the probabilities used for classification are returned as an attribute.

parallel

A logical value. If TRUE, parallelization is carried out.

...

Additional arguments used if method = "fs".