Predict from an MoTBF Bayesian Network
# S3 method for motbf_fit
predict(
object,
target,
data,
method = NULL,
prob = FALSE,
parallel = FALSE,
...
)An object of class "motbf_fit"
A character string indicating the variable to be predicted
A data frame containing the predictive variables
A character string indicating the method to perform the inference. Options are NULL, "ve" (variable elimination) and "fs" (forward sampling).
A logical value. If TRUE, the probabilities used for classification are returned as an attribute.
A logical value. If TRUE, parallelization is carried out.
Additional arguments used if method = "fs".